==> magpie-data-0.5.8-sources.jar: io/openraven/magpie/data/aws/glacier/GlacierVault.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.glacier;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.glacier.model.DescribeVaultOutput;

import java.time.Instant;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = GlacierVault.TABLE_NAME)
public class GlacierVault extends AWSResource {

  protected static final String TABLE_NAME = "awsglaciervault";
  public static final String RESOURCE_TYPE = "AWS::Glacier::Vault";

  public GlacierVault() {
    this.resourceType = RESOURCE_TYPE;
  }

  public GlacierVault(String regionId, String accountId, DescribeVaultOutput vault) {
    this.awsRegion = regionId;
    this.awsAccountId = accountId;
    this.arn = vault.vaultARN();
    this.resourceName = vault.vaultName();
    this.configuration = PayloadUtils.update(vault);
    this.resourceType = RESOURCE_TYPE;
    this.createdIso = Instant.parse(vault.creationDate());
    this.updatedIso = Instant.parse(vault.lastInventoryDate());
  }
}

==> magpie-data-0.11.6-sources.jar: io/openraven/magpie/data/aws/glacier/GlacierVault.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.glacier;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.glacier.model.DescribeVaultOutput;

import java.time.Instant;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = GlacierVault.TABLE_NAME)
public class GlacierVault extends AWSResource {

  protected static final String TABLE_NAME = "awsglaciervault";
  public static final String RESOURCE_TYPE = "AWS::Glacier::Vault";

  public GlacierVault() {
    this.resourceType = RESOURCE_TYPE;
  }

  public GlacierVault(String regionId, String accountId, DescribeVaultOutput vault) {
    this.awsRegion = regionId;
    this.awsAccountId = accountId;
    this.arn = vault.vaultARN();
    this.resourceName = vault.vaultName();
    this.configuration = PayloadUtils.update(vault);
    this.resourceType = RESOURCE_TYPE;
    this.createdIso = Instant.parse(vault.creationDate());
    this.updatedIso = Instant.parse(vault.lastInventoryDate());
  }
}
